/***************************************************************************
                 job_countdata.h  -  description
                             -------------------
    begin                : Wed Jan 8 2002
    copyright            : (C) 2003 by Markus Kalkbrenner
    email                : mkalkbrenner@sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef JOB_COUNTDATA_H
#define JOB_COUNTDATA_H

#include "prokyon.h"

#include "jobbase.h"

class Job_CountData : public JobBase  {
public:
    Job_CountData();

    int type() {
        return JOB_COUNT_DATA;
    }

    void run();

    ~Job_CountData();

};

#endif

